summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-10-11 13:58:41 -0500
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-10-11 13:58:41 -0500
commitbc91b96ff7b72ed86e02274adf9404b54ae2922c (patch)
tree0ea8dfc3db1f6ce73fbd0ae100e27415273d14f7 /crawl-ref/source/enum.h
parent9382227d37bbc14d4ef2f7a3d832df03d9c8c02c (diff)
downloadcrawl-ref-bc91b96ff7b72ed86e02274adf9404b54ae2922c.tar.gz
crawl-ref-bc91b96ff7b72ed86e02274adf9404b54ae2922c.zip
Properly indicate the source of Kiku's torment.
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 563e65015e..7a18318241 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -2932,12 +2932,13 @@ enum targetting_type
enum torment_source_type
{
- TORMENT_GENERIC = -1,
- TORMENT_CARDS = -2, // Symbol of torment
- TORMENT_SPWLD = -3, // Special wield torment
- TORMENT_SCROLL = -4,
- TORMENT_SPELL = -5, // SPELL_SYMBOL_OF_TORMENT
- TORMENT_XOM = -6 // Xom effect
+ TORMENT_GENERIC = -1,
+ TORMENT_CARDS = -2, // Symbol of torment
+ TORMENT_SPWLD = -3, // Special wield torment
+ TORMENT_SCROLL = -4,
+ TORMENT_SPELL = -5, // SPELL_SYMBOL_OF_TORMENT
+ TORMENT_XOM = -6, // Xom effect
+ TORMENT_KIKUBAAQUDGHA = -7 // Kikubaaqudgha effect
};
enum trap_type // env.trap_type[]